# coding: utf-8

"""
    Ivy Analytics API

    API for data ingestion

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from ivyanalytics.models.api_success_response import ApiSuccessResponse

class TestApiSuccessResponse(unittest.TestCase):
    """ApiSuccessResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiSuccessResponse:
        """Test ApiSuccessResponse
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiSuccessResponse`
        """
        model = ApiSuccessResponse()
        if include_optional:
            return ApiSuccessResponse(
                status = 'success',
                message = '',
                data = None
            )
        else:
            return ApiSuccessResponse(
                message = '',
        )
        """

    def testApiSuccessResponse(self):
        """Test ApiSuccessResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Ivy Analytics API

    API for data ingestion

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from ivyanalytics.models.assigned_to import AssignedTo
from ivyanalytics.models.author import Author
from ivyanalytics.models.body import Body
from ivyanalytics.models.external_id import ExternalId
from typing import Optional, Set
from typing_extensions import Self

class Conversation(BaseModel):
    """
    Conversation
    """ # noqa: E501
    type: StrictStr
    id: StrictStr
    part_type: StrictStr
    body: Optional[Body] = None
    created_at: StrictInt
    updated_at: StrictInt
    notified_at: StrictInt
    assigned_to: Optional[AssignedTo] = None
    author: Author
    attachments: List[Any]
    external_id: Optional[ExternalId] = None
    redacted: StrictBool
    __properties: ClassVar[List[str]] = ["type", "id", "part_type", "body", "created_at", "updated_at", "notified_at", "assigned_to", "author", "attachments", "external_id", "redacted"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of Conversation from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of body
        if self.body:
            _dict['body'] = self.body.to_dict()
        # override the default output from pydantic by calling `to_dict()` of assigned_to
        if self.assigned_to:
            _dict['assigned_to'] = self.assigned_to.to_dict()
        # override the default output from pydantic by calling `to_dict()` of author
        if self.author:
            _dict['author'] = self.author.to_dict()
        # override the default output from pydantic by calling `to_dict()` of external_id
        if self.external_id:
            _dict['external_id'] = self.external_id.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of Conversation from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "type": obj.get("type"),
            "id": obj.get("id"),
            "part_type": obj.get("part_type"),
            "body": Body.from_dict(obj["body"]) if obj.get("body") is not None else None,
            "created_at": obj.get("created_at"),
            "updated_at": obj.get("updated_at"),
            "notified_at": obj.get("notified_at"),
            "assigned_to": AssignedTo.from_dict(obj["assigned_to"]) if obj.get("assigned_to") is not None else None,
            "author": Author.from_dict(obj["author"]) if obj.get("author") is not None else None,
            "attachments": obj.get("attachments"),
            "external_id": ExternalId.from_dict(obj["external_id"]) if obj.get("external_id") is not None else None,
            "redacted": obj.get("redacted")
        })
        return _obj





# coding: utf-8

# flake8: noqa

"""
    Ivy Analytics API

    API for data ingestion

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


__version__ = "1.0.0"

import warnings

# import apis into sdk package
from ivyanalytics.api.conversation_api import ConversationApi
from ivyanalytics.api.index_api import IndexApi
from ivyanalytics.api.intercom_api import IntercomApi

# import ApiClient
from ivyanalytics.api_response import ApiResponse
from ivyanalytics.api_client import ApiClient
from ivyanalytics.configuration import Configuration
from ivyanalytics.exceptions import OpenApiException
from ivyanalytics.exceptions import ApiTypeError
from ivyanalytics.exceptions import ApiValueError
from ivyanalytics.exceptions import ApiKeyError
from ivyanalytics.exceptions import ApiAttributeError
from ivyanalytics.exceptions import ApiException

# import models into sdk package
from ivyanalytics.models.api_success_response import ApiSuccessResponse
from ivyanalytics.models.assigned_to import AssignedTo
from ivyanalytics.models.author import Author
from ivyanalytics.models.body import Body
from ivyanalytics.models.conversation import Conversation
from ivyanalytics.models.conversation_created_at import ConversationCreatedAt
from ivyanalytics.models.conversation_data_schema import ConversationDataSchema
from ivyanalytics.models.conversation_parts import ConversationParts
from ivyanalytics.models.conversation_schema import ConversationSchema
from ivyanalytics.models.conversation_source import ConversationSource
from ivyanalytics.models.data import Data
from ivyanalytics.models.data_item import DataItem
from ivyanalytics.models.external_id import ExternalId
from ivyanalytics.models.greeting import Greeting
from ivyanalytics.models.http_validation_error import HTTPValidationError
from ivyanalytics.models.intercom_notification_event_schema import IntercomNotificationEventSchema
from ivyanalytics.models.item import Item
from ivyanalytics.models.message_schema import MessageSchema
from ivyanalytics.models.metadata import Metadata
from ivyanalytics.models.name import Name
from ivyanalytics.models.role_enum_schema import RoleEnumSchema
from ivyanalytics.models.validation_error import ValidationError
from ivyanalytics.models.validation_error_loc_inner import ValidationErrorLocInner
from ivyanalytics.models.webhook_topics import WebhookTopics

# Supress warnings - This warning is default behaviour and cannot be handled
warnings.filterwarnings("ignore")



# coding: utf-8

"""
    Ivy Analytics API

    API for data ingestion

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from ivyanalytics.models.data_item import DataItem

class TestDataItem(unittest.TestCase):
    """DataItem unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> DataItem:
        """Test DataItem
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `DataItem`
        """
        model = DataItem()
        if include_optional:
            return DataItem(
                type = '',
                item = ivyanalytics.models.item.Item(
                    type = '', 
                    id = '', 
                    created_at = 56, 
                    updated_at = 56, 
                    source = ivyanalytics.models.conversation_source.ConversationSource(
                        type = '', 
                        id = '', 
                        author = ivyanalytics.models.author.Author(
                            id = '', 
                            type = '', 
                            name = null, 
                            email = '', ), 
                        body = '', ), 
                    conversation_parts = ivyanalytics.models.conversation_parts.ConversationParts(
                        type = '', 
                        conversation_parts = [
                            ivyanalytics.models.conversation.Conversation(
                                type = '', 
                                id = '', 
                                part_type = '', 
                                body = null, 
                                created_at = 56, 
                                updated_at = 56, 
                                notified_at = 56, 
                                assigned_to = null, 
                                author = ivyanalytics.models.author.Author(
                                    id = '', 
                                    type = '', 
                                    email = '', ), 
                                attachments = [
                                    null
                                    ], 
                                external_id = null, 
                                redacted = True, )
                            ], 
                        total_count = 56, ), )
            )
        else:
            return DataItem(
                type = '',
                item = ivyanalytics.models.item.Item(
                    type = '', 
                    id = '', 
                    created_at = 56, 
                    updated_at = 56, 
                    source = ivyanalytics.models.conversation_source.ConversationSource(
                        type = '', 
                        id = '', 
                        author = ivyanalytics.models.author.Author(
                            id = '', 
                            type = '', 
                            name = null, 
                            email = '', ), 
                        body = '', ), 
                    conversation_parts = ivyanalytics.models.conversation_parts.ConversationParts(
                        type = '', 
                        conversation_parts = [
                            ivyanalytics.models.conversation.Conversation(
                                type = '', 
                                id = '', 
                                part_type = '', 
                                body = null, 
                                created_at = 56, 
                                updated_at = 56, 
                                notified_at = 56, 
                                assigned_to = null, 
                                author = ivyanalytics.models.author.Author(
                                    id = '', 
                                    type = '', 
                                    email = '', ), 
                                attachments = [
                                    null
                                    ], 
                                external_id = null, 
                                redacted = True, )
                            ], 
                        total_count = 56, ), ),
        )
        """

    def testDataItem(self):
        """Test DataItem"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Ivy Analytics API

    API for data ingestion

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class WebhookTopics(str, Enum):
    """
    WebhookTopics
    """

    """
    allowed enum values
    """
    CONVERSATION_DOT_ADMIN_DOT_REPLIED = 'conversation.admin.replied'
    CONVERSATION_DOT_USER_DOT_REPLIED = 'conversation.user.replied'
    CONVERSATION_DOT_USER_DOT_CREATED = 'conversation.user.created'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of WebhookTopics from a JSON string"""
        return cls(json.loads(json_str))





# coding: utf-8

"""
    Ivy Analytics API

    API for data ingestion

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from ivyanalytics.models.item import Item

class TestItem(unittest.TestCase):
    """Item unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> Item:
        """Test Item
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `Item`
        """
        model = Item()
        if include_optional:
            return Item(
                type = '',
                id = '',
                created_at = 56,
                updated_at = 56,
                source = ivyanalytics.models.conversation_source.ConversationSource(
                    type = '', 
                    id = '', 
                    author = ivyanalytics.models.author.Author(
                        id = '', 
                        type = '', 
                        name = null, 
                        email = '', ), 
                    body = '', ),
                conversation_parts = ivyanalytics.models.conversation_parts.ConversationParts(
                    type = '', 
                    conversation_parts = [
                        ivyanalytics.models.conversation.Conversation(
                            type = '', 
                            id = '', 
                            part_type = '', 
                            body = null, 
                            created_at = 56, 
                            updated_at = 56, 
                            notified_at = 56, 
                            assigned_to = null, 
                            author = ivyanalytics.models.author.Author(
                                id = '', 
                                type = '', 
                                name = null, 
                                email = '', ), 
                            attachments = [
                                null
                                ], 
                            external_id = null, 
                            redacted = True, )
                        ], 
                    total_count = 56, )
            )
        else:
            return Item(
                type = '',
                id = '',
                created_at = 56,
                updated_at = 56,
                source = ivyanalytics.models.conversation_source.ConversationSource(
                    type = '', 
                    id = '', 
                    author = ivyanalytics.models.author.Author(
                        id = '', 
                        type = '', 
                        name = null, 
                        email = '', ), 
                    body = '', ),
                conversation_parts = ivyanalytics.models.conversation_parts.ConversationParts(
                    type = '', 
                    conversation_parts = [
                        ivyanalytics.models.conversation.Conversation(
                            type = '', 
                            id = '', 
                            part_type = '', 
                            body = null, 
                            created_at = 56, 
                            updated_at = 56, 
                            notified_at = 56, 
                            assigned_to = null, 
                            author = ivyanalytics.models.author.Author(
                                id = '', 
                                type = '', 
                                name = null, 
                                email = '', ), 
                            attachments = [
                                null
                                ], 
                            external_id = null, 
                            redacted = True, )
                        ], 
                    total_count = 56, ),
        )
        """

    def testItem(self):
        """Test Item"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Ivy Analytics API

    API for data ingestion

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from ivyanalytics.models.conversation import Conversation

class TestConversation(unittest.TestCase):
    """Conversation unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> Conversation:
        """Test Conversation
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `Conversation`
        """
        model = Conversation()
        if include_optional:
            return Conversation(
                type = '',
                id = '',
                part_type = '',
                body = None,
                created_at = 56,
                updated_at = 56,
                notified_at = 56,
                assigned_to = None,
                author = ivyanalytics.models.author.Author(
                    id = '', 
                    type = '', 
                    name = null, 
                    email = '', ),
                attachments = [
                    null
                    ],
                external_id = None,
                redacted = True
            )
        else:
            return Conversation(
                type = '',
                id = '',
                part_type = '',
                created_at = 56,
                updated_at = 56,
                notified_at = 56,
                author = ivyanalytics.models.author.Author(
                    id = '', 
                    type = '', 
                    name = null, 
                    email = '', ),
                attachments = [
                    null
                    ],
                redacted = True,
        )
        """

    def testConversation(self):
        """Test Conversation"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Ivy Analytics API

    API for data ingestion

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from ivyanalytics.models.conversation_schema import ConversationSchema

class TestConversationSchema(unittest.TestCase):
    """ConversationSchema unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ConversationSchema:
        """Test ConversationSchema
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ConversationSchema`
        """
        model = ConversationSchema()
        if include_optional:
            return ConversationSchema(
                conversation_id = '',
                tenant_id = '',
                conversation_created_at = None,
                messages = [
                    ivyanalytics.models.message_schema.MessageSchema(
                        id = '', 
                        role = 'user', 
                        body = '', 
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                    ],
                metadata = None
            )
        else:
            return ConversationSchema(
                conversation_id = '',
                tenant_id = '',
                messages = [
                    ivyanalytics.models.message_schema.MessageSchema(
                        id = '', 
                        role = 'user', 
                        body = '', 
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                    ],
        )
        """

    def testConversationSchema(self):
        """Test ConversationSchema"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Ivy Analytics API

    API for data ingestion

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from ivyanalytics.models.conversation_data_schema import ConversationDataSchema

class TestConversationDataSchema(unittest.TestCase):
    """ConversationDataSchema unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ConversationDataSchema:
        """Test ConversationDataSchema
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ConversationDataSchema`
        """
        model = ConversationDataSchema()
        if include_optional:
            return ConversationDataSchema(
                conversations = [
                    ivyanalytics.models.conversation_schema.ConversationSchema(
                        conversation_id = '', 
                        tenant_id = '', 
                        conversation_created_at = null, 
                        messages = [
                            ivyanalytics.models.message_schema.MessageSchema(
                                id = '', 
                                role = 'user', 
                                body = '', 
                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                            ], 
                        metadata = null, )
                    ],
                created_at = '2024-03-05T07:37:50.187126+00:00'
            )
        else:
            return ConversationDataSchema(
                conversations = [
                    ivyanalytics.models.conversation_schema.ConversationSchema(
                        conversation_id = '', 
                        tenant_id = '', 
                        conversation_created_at = null, 
                        messages = [
                            ivyanalytics.models.message_schema.MessageSchema(
                                id = '', 
                                role = 'user', 
                                body = '', 
                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                            ], 
                        metadata = null, )
                    ],
        )
        """

    def testConversationDataSchema(self):
        """Test ConversationDataSchema"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Ivy Analytics API

    API for data ingestion

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from ivyanalytics.models.intercom_notification_event_schema import IntercomNotificationEventSchema

class TestIntercomNotificationEventSchema(unittest.TestCase):
    """IntercomNotificationEventSchema unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> IntercomNotificationEventSchema:
        """Test IntercomNotificationEventSchema
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `IntercomNotificationEventSchema`
        """
        model = IntercomNotificationEventSchema()
        if include_optional:
            return IntercomNotificationEventSchema(
                app_id = '',
                data = ivyanalytics.models.data_item.DataItem(
                    type = '', 
                    item = ivyanalytics.models.item.Item(
                        type = '', 
                        id = '', 
                        created_at = 56, 
                        updated_at = 56, 
                        source = ivyanalytics.models.conversation_source.ConversationSource(
                            type = '', 
                            id = '', 
                            author = ivyanalytics.models.author.Author(
                                id = '', 
                                type = '', 
                                name = null, 
                                email = '', ), 
                            body = '', ), 
                        conversation_parts = ivyanalytics.models.conversation_parts.ConversationParts(
                            type = '', 
                            conversation_parts = [
                                ivyanalytics.models.conversation.Conversation(
                                    type = '', 
                                    id = '', 
                                    part_type = '', 
                                    body = null, 
                                    created_at = 56, 
                                    updated_at = 56, 
                                    notified_at = 56, 
                                    assigned_to = null, 
                                    author = ivyanalytics.models.author.Author(
                                        id = '', 
                                        type = '', 
                                        email = '', ), 
                                    attachments = [
                                        null
                                        ], 
                                    external_id = null, 
                                    redacted = True, )
                                ], 
                            total_count = 56, ), ), ),
                topic = 'conversation.admin.replied'
            )
        else:
            return IntercomNotificationEventSchema(
                app_id = '',
                data = ivyanalytics.models.data_item.DataItem(
                    type = '', 
                    item = ivyanalytics.models.item.Item(
                        type = '', 
                        id = '', 
                        created_at = 56, 
                        updated_at = 56, 
                        source = ivyanalytics.models.conversation_source.ConversationSource(
                            type = '', 
                            id = '', 
                            author = ivyanalytics.models.author.Author(
                                id = '', 
                                type = '', 
                                name = null, 
                                email = '', ), 
                            body = '', ), 
                        conversation_parts = ivyanalytics.models.conversation_parts.ConversationParts(
                            type = '', 
                            conversation_parts = [
                                ivyanalytics.models.conversation.Conversation(
                                    type = '', 
                                    id = '', 
                                    part_type = '', 
                                    body = null, 
                                    created_at = 56, 
                                    updated_at = 56, 
                                    notified_at = 56, 
                                    assigned_to = null, 
                                    author = ivyanalytics.models.author.Author(
                                        id = '', 
                                        type = '', 
                                        email = '', ), 
                                    attachments = [
                                        null
                                        ], 
                                    external_id = null, 
                                    redacted = True, )
                                ], 
                            total_count = 56, ), ), ),
                topic = 'conversation.admin.replied',
        )
        """

    def testIntercomNotificationEventSchema(self):
        """Test IntercomNotificationEventSchema"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Ivy Analytics API

    API for data ingestion

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from ivyanalytics.models.webhook_topics import WebhookTopics

class TestWebhookTopics(unittest.TestCase):
    """WebhookTopics unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testWebhookTopics(self):
        """Test WebhookTopics"""
        # inst = WebhookTopics()

if __name__ == '__main__':
    unittest.main()



# flake8: noqa

# import apis into api package
from ivyanalytics.api.conversation_api import ConversationApi
from ivyanalytics.api.index_api import IndexApi
from ivyanalytics.api.intercom_api import IntercomApi




# coding: utf-8

"""
    Ivy Analytics API

    API for data ingestion

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from ivyanalytics.models.conversation_parts import ConversationParts

class TestConversationParts(unittest.TestCase):
    """ConversationParts unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ConversationParts:
        """Test ConversationParts
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ConversationParts`
        """
        model = ConversationParts()
        if include_optional:
            return ConversationParts(
                type = '',
                conversation_parts = [
                    ivyanalytics.models.conversation.Conversation(
                        type = '', 
                        id = '', 
                        part_type = '', 
                        body = null, 
                        created_at = 56, 
                        updated_at = 56, 
                        notified_at = 56, 
                        assigned_to = null, 
                        author = ivyanalytics.models.author.Author(
                            id = '', 
                            type = '', 
                            name = null, 
                            email = '', ), 
                        attachments = [
                            null
                            ], 
                        external_id = null, 
                        redacted = True, )
                    ],
                total_count = 56
            )
        else:
            return ConversationParts(
                type = '',
                conversation_parts = [
                    ivyanalytics.models.conversation.Conversation(
                        type = '', 
                        id = '', 
                        part_type = '', 
                        body = null, 
                        created_at = 56, 
                        updated_at = 56, 
                        notified_at = 56, 
                        assigned_to = null, 
                        author = ivyanalytics.models.author.Author(
                            id = '', 
                            type = '', 
                            name = null, 
                            email = '', ), 
                        attachments = [
                            null
                            ], 
                        external_id = null, 
                        redacted = True, )
                    ],
                total_count = 56,
        )
        """

    def testConversationParts(self):
        """Test ConversationParts"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Ivy Analytics API

    API for data ingestion

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501
from setuptools import setup, find_packages  # noqa: H301

# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools
NAME = "ivyanalytics"
VERSION = "0.0.b0"
PYTHON_REQUIRES = ">=3.7"
REQUIRES = [
    "urllib3 >= 1.25.3, < 2.1.0",
    "python-dateutil",
    "pydantic >= 2",
    "typing-extensions >= 4.7.1",
]

with open('README.md') as readme:
    readme_content = readme.read()

setup(
    name=NAME,
    version=VERSION,
    description="Ivy Analytics API",
    author="This SDK is used to ingest data into Ivy Analytics.",
    author_email="hello@ivyanalytics.io",
    url="https://www.ivyanalytics.io",
    keywords=["Ivy Analytics", "Conversational Analytics"],
    install_requires=REQUIRES,
    packages=find_packages(exclude=["test", "tests"]),
    include_package_data=True,
    long_description_content_type='text/markdown',
    long_description=readme_content,
    package_data={"ivyanalytics": ["py.typed"]},
    classifiers=[
        "Intended Audience :: Developers",
        "License :: OSI Approved :: MIT License",

        # List of supported Python versions
        # Make sure that this is reflected in .github/workflows/python.yml as well
        "Programming Language :: Python",
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.7',

        "Topic :: Software Development :: Libraries :: Python Modules",
    ]
)



# coding: utf-8

# flake8: noqa
"""
    Ivy Analytics API

    API for data ingestion

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


# import models into model package
from ivyanalytics.models.api_success_response import ApiSuccessResponse
from ivyanalytics.models.assigned_to import AssignedTo
from ivyanalytics.models.author import Author
from ivyanalytics.models.body import Body
from ivyanalytics.models.conversation import Conversation
from ivyanalytics.models.conversation_created_at import ConversationCreatedAt
from ivyanalytics.models.conversation_data_schema import ConversationDataSchema
from ivyanalytics.models.conversation_parts import ConversationParts
from ivyanalytics.models.conversation_schema import ConversationSchema
from ivyanalytics.models.conversation_source import ConversationSource
from ivyanalytics.models.data import Data
from ivyanalytics.models.data_item import DataItem
from ivyanalytics.models.external_id import ExternalId
from ivyanalytics.models.greeting import Greeting
from ivyanalytics.models.http_validation_error import HTTPValidationError
from ivyanalytics.models.intercom_notification_event_schema import IntercomNotificationEventSchema
from ivyanalytics.models.item import Item
from ivyanalytics.models.message_schema import MessageSchema
from ivyanalytics.models.metadata import Metadata
from ivyanalytics.models.name import Name
from ivyanalytics.models.role_enum_schema import RoleEnumSchema
from ivyanalytics.models.validation_error import ValidationError
from ivyanalytics.models.validation_error_loc_inner import ValidationErrorLocInner
from ivyanalytics.models.webhook_topics import WebhookTopics



# coding: utf-8

"""
    Ivy Analytics API

    API for data ingestion

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from ivyanalytics.api.intercom_api import IntercomApi


class TestIntercomApi(unittest.TestCase):
    """IntercomApi unit test stubs"""

    def setUp(self) -> None:
        self.api = IntercomApi()

    def tearDown(self) -> None:
        pass

    def test_conversations_v1_intercom_conversations_post(self) -> None:
        """Test case for conversations_v1_intercom_conversations_post

        Conversations
        """
        pass


if __name__ == '__main__':
    unittest.main()
